Changelog
---------

0.2.1
~~~~~

* Fix compatibility with pypy

0.2.0
~~~~~

* Extend support to pytest >= 3.0.0
* Use the verbosity arg to decide to print or not the fixtures docstrings
* Remove the green color when logging unused fixtures
* Minor improvements to README

0.1.0
~~~~~

* First release
